/*
 * Copyright (c) 2021, STMicroelectronics.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*
 * @file	version_def.h
 * @brief	generated version definition for OpenAMP library.
 */

#ifndef __OPENAMP_VERSION_DEF__H__
#define __OPENAMP_VERSION_DEF__H__

/*  values come from cmake/option.cmake */

#define OPENAMP_VERSION_MAJOR  1
#define OPENAMP_VERSION_MINOR  9
#define OPENAMP_VERSION_PATCH  0
#define OPENAMP_VERSION        "1.9.0"

#endif /* __OPENAMP_VERSION_DEF__H__ */
